import{g as _}from"./api.2921acd7.js";import{W as g}from"./Watermark.f63fb27f.js";import{i as h}from"./metadata.9cd5a8e3.js";import{a as b}from"./asyncComputed.0b7f3eaf.js";import{W as k}from"./WidgetsFrame.bae57e91.js";import{F as w}from"./PhArrowSquareOut.vue.69153380.js";import{d as v,eM as x,f as C,u as e,o as s,c as l,w as a,ev as D,b as n,cN as d,ar as f,et as F,eC as I,cV as u,eD as V,ez as W,aD as z,R as N}from"./vue-router.637ad36e.js";import"./index.952610e6.js";import{C as T}from"./Card.6af2f5b2.js";import"./router.c2ded2b1.js";import"./runnerData.8e7195b2.js";import"./url.c1cbace3.js";import"./PhCheckCircle.vue.92a8a97d.js";import"./PhKanban.vue.0ae2296c.js";import"./PhWebhooksLogo.vue.3f87c53c.js";import"./TabPane.db2c1289.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="6e205068-4758-41c0-b35c-3434b4a6034a",o._sentryDebugIdIdentifier="sentry-dbid-6e205068-4758-41c0-b35c-3434b4a6034a")}catch{}})();const B=v({__name:"Home",setup(o){const i=x(),{result:t}=b(_),m=C(()=>{var r;return((r=t.value)==null?void 0:r.sidebar.filter(p=>p.id!=="home"))||[]}),y=r=>{i.push({path:`/${r}`})};return(r,p)=>e(t)?(s(),l(k,{key:0,class:"home-container","main-color":e(t).mainColor,theme:e(t).theme,"font-family":e(t).fontFamily},{default:a(()=>[n(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:a(()=>[m.value.length===0?(s(),l(e(d),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:a(()=>[f(" There are no forms available for you. ")]),_:1})):(s(!0),F(z,{key:1},I(m.value,c=>(s(),l(e(T),{key:c.id,class:"form-card",onClick:H=>y(c.path)},{default:a(()=>[n(e(u),{gap:"large",align:"center",justify:"space-between"},{default:a(()=>[(s(),l(V(e(h)(c.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),n(e(d),{style:{"font-size":"18px","font-weight":"500"}},{default:a(()=>[f(W(c.name),1)]),_:2},1024),n(e(w),{size:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}),n(g,{class:"watermark","page-id":"home",locale:e(t).language},null,8,["locale"])]),_:1},8,["main-color","theme","font-family"])):D("",!0)}});const X=N(B,[["__scopeId","data-v-06807ab2"]]);export{X as default};
//# sourceMappingURL=Home.e47a5000.js.map
