import{d as n,o as a,et as s,a as d,dA as c,ex as r,R as l}from"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ba36b02c-ca29-406c-aeb7-9c43839acd0b",e._sentryDebugIdIdentifier="sentry-dbid-ba36b02c-ca29-406c-aeb7-9c43839acd0b")}catch{}})();const _={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(a(),s("div",_,[d("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[c(t.$slots,"default",{},void 0,!0)],2)]))}});const f=l(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.aeecd886.js.map
