import"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="5d0b901d-a412-4bc9-9d5f-3db83dea3e3a",e._sentryDebugIdIdentifier="sentry-dbid-5d0b901d-a412-4bc9-9d5f-3db83dea3e3a")}catch{}})();const o=(...e)=>window.fetch(...e);export{o as l};
//# sourceMappingURL=fetch.a7f25938.js.map
