import{g as m}from"./api.2921acd7.js";import{_ as u}from"./Login.vue_vue_type_script_setup_true_lang.8f4cdf47.js";import{u as p}from"./router.c2ded2b1.js";import{a as d}from"./asyncComputed.0b7f3eaf.js";import{W as f}from"./WidgetsFrame.bae57e91.js";import{d as _,eM as l,eA as y,u as r,o as b,c as g,w as h,ev as w,b as I,R as k}from"./vue-router.637ad36e.js";import"./runnerData.8e7195b2.js";import"./url.c1cbace3.js";import"./CircularLoading.91222c8d.js";import"./index.13a24099.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="81976201-0c34-4703-905a-06c3b58cb66b",e._sentryDebugIdIdentifier="sentry-dbid-81976201-0c34-4703-905a-06c3b58cb66b")}catch{}})();const v=_({__name:"Login",setup(e){const t=l(),s=y(),{result:o}=d(m),c=p(),i=async()=>{await c.signUp();const{redirect:a,...n}=s.query;if(a){await t.push({path:a,query:n,params:s.params});return}t.push({name:"playerHome",query:n})};return(a,n)=>r(o)?(b(),g(f,{key:0,"main-color":r(o).mainColor,theme:r(o).theme,"font-family":r(o).fontFamily,class:"runner"},{default:h(()=>[I(u,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):w("",!0)}});const S=k(v,[["__scopeId","data-v-9e2c7105"]]);export{S as default};
//# sourceMappingURL=Login.b49329e1.js.map
