[data-v-4bed0b2c]:root{--main-font-family: DM Sans, sans-serif}[data-v-4bed0b2c]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-4bed0b2c]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-4bed0b2c]{background-color:#fff;padding:10px}.watermark[data-v-4bed0b2c]{border-radius:8px 8px 0 0;background-color:#ffffffe6;padding:4px 12px;color:#5a677a;cursor:pointer;text-decoration:none;font-size:11px;display:flex;align-items:center;position:fixed;bottom:0;right:20px}.watermark .logo[data-v-4bed0b2c]{margin-left:10px;margin-right:8px}.watermark b[data-v-4bed0b2c]{font-weight:500;color:#5a677a}*[data-v-4bed0b2c]{font-family:var(--main-font-family)}
