import{g as _}from"./api.2921acd7.js";import{u as g}from"./router.c2ded2b1.js";import{d as v,L as h,N as u,e as T,u as e,o as s,c as n,w as y,ev as i,b as p,R as W}from"./vue-router.637ad36e.js";import{K,_ as R,W as I,P,b as S}from"./WorkflowView.150d9829.js";import{P as V}from"./api.fb2155e2.js";import{a as x}from"./asyncComputed.0b7f3eaf.js";import{W as C}from"./WidgetsFrame.bae57e91.js";import{A as c,T as A}from"./TabPane.db2c1289.js";import"./Card.6af2f5b2.js";import"./runnerData.8e7195b2.js";import"./url.c1cbace3.js";import"./fetch.a7f25938.js";import"./linters.45f0bd9a.js";import"./scripts.9fe343da.js";import"./record.833ab838.js";import"./metadata.9cd5a8e3.js";import"./PhCheckCircle.vue.92a8a97d.js";import"./PhKanban.vue.0ae2296c.js";import"./PhWebhooksLogo.vue.3f87c53c.js";import"./ant-design.5377a580.js";import"./index.faf7cd82.js";import"./index.ba283bad.js";import"./index.477bbb1c.js";import"./index.c0d6d885.js";import"./CollapsePanel.703584f9.js";import"./index.5388dc8c.js";import"./index.cf05a826.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.5e489784.js";import"./model.9e62b22b.js";import"./workspaces.29615a64.js";import"./validations.2be13234.js";import"./string.876500c9.js";import"./PhArrowSquareOut.vue.69153380.js";import"./index.292db4f5.js";import"./Badge.7cdb210c.js";import"./index.13a24099.js";import"./uuid.9a0cf3c3.js";import"./LoadingOutlined.e5ed65d8.js";import"./DeleteOutlined.b63ba760.js";import"./PhDownloadSimple.vue.8d040345.js";import"./utils.85ed511a.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[m]="ba983e78-ae31-4806-a8c1-36a1f453e8ef",o._sentryDebugIdIdentifier="sentry-dbid-ba983e78-ae31-4806-a8c1-36a1f453e8ef")}catch{}})();const D=v({__name:"Threads",setup(o){const t=g().authHeaders,{result:r}=x(_),d=new V(t),l=new P(t),b=new S(t),k=new h(u.array(u.string()),"kanban-selected-stages"),a=T("kanban");return(B,f)=>e(r)?(s(),n(C,{key:0,class:"threads-view","main-color":e(r).mainColor,theme:e(r).theme,"font-family":e(r).fontFamily},{default:y(()=>[p(e(A),{activeKey:a.value,"onUpdate:activeKey":f[0]||(f[0]=w=>a.value=w)},{default:y(()=>[p(e(c),{key:"kanban",tab:"Kanban View"}),p(e(c),{key:"table",tab:"Table View"}),p(e(c),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(s(),n(K,{key:0,"kanban-repository":e(l),"kanban-stages-storage":e(k),"stage-run-repository":e(b)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):i("",!0),a.value==="table"?(s(),n(R,{key:1,"kanban-repository":e(l)},null,8,["kanban-repository"])):i("",!0),a.value==="workflow"?(s(),n(I,{key:2,"kanban-repository":e(l),"workflow-api":e(d)},null,8,["kanban-repository","workflow-api"])):i("",!0)]),_:1},8,["main-color","theme","font-family"])):i("",!0)}});const We=W(D,[["__scopeId","data-v-cd1d6c57"]]);export{We as default};
//# sourceMappingURL=Threads.29df6c22.js.map
