import{L as v}from"./Logo.48fe3cc3.js";import{a as k}from"./asyncComputed.0b7f3eaf.js";import{d as A,eA as x,eM as C,f as I,o as i,et as N,b as n,w as t,u as e,c as _,ev as m,f3 as s,ar as a,ez as l,cR as B,cN as p,bG as D,a as T,cO as E,R}from"./vue-router.637ad36e.js";import{g as V}from"./api.2921acd7.js";import{C as L}from"./Card.6af2f5b2.js";import"./router.c2ded2b1.js";import"./runnerData.8e7195b2.js";import"./url.c1cbace3.js";import"./TabPane.db2c1289.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new z().stack;c&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[c]="063a192d-2712-4513-9129-2103bbb4a8a5",o._sentryDebugIdIdentifier="sentry-dbid-063a192d-2712-4513-9129-2103bbb4a8a5")}catch{}})();const G={class:"inner-content"},H={class:"card-content"},j=A({__name:"Error",setup(o){var b,y,h;const c=x(),f=C(),{result:u}=k(V),g=(h=(b=u.value)==null?void 0:b.name)!=null?h:(y=u.value)==null?void 0:y.brandName,r=I(()=>{const{status:d}=c.params;switch(d){case"404":return{status:d,title:s.translate("i18n_page_not_found"),message:s.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:d,title:s.translate("i18n_access_denied"),message:s.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:s.translate("i18n_internal_error"),message:s.translate("i18n_internal_error_message"),showAd:!1}}}),w=()=>{f.push({name:"playerHome"})};return(d,M)=>(i(),N("div",G,[n(e(B),null,{default:t(()=>[a(l(r.value.title),1)]),_:1}),n(e(p),{class:"message"},{default:t(()=>[a(l(r.value.message),1)]),_:1}),r.value.action?(i(),_(e(D),{key:0,type:"link",onClick:w},{default:t(()=>[a(l(r.value.action),1)]),_:1})):m("",!0),r.value.showAd?(i(),_(e(L),{key:1,bordered:!1,class:"card"},{default:t(()=>[T("div",H,[n(v,{style:{"margin-bottom":"10px"}}),n(e(p),null,{default:t(()=>[a("This page is part of "+l(e(g)?`the ${e(g)}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(u)?(i(),_(e(p),{key:0},{default:t(()=>[a("Automate your own processes by getting started "),n(e(E),{href:"https://abstra.io"},{default:t(()=>[a("here")]),_:1}),a(".")]),_:1})):m("",!0)])]),_:1})):m("",!0)]))}});const z=R(j,[["__scopeId","data-v-599c1508"]]);export{z as default};
//# sourceMappingURL=Error.2a7c999b.js.map
