import{B as d}from"./BookOutlined.c02a6591.js";import{d as c,o as s,c as l,w as o,b as f,u as n,dA as u,et as i,ar as p,aD as b,bG as y}from"./vue-router.637ad36e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="1e4411b6-ce59-4566-b12e-53aac34e3ce2",t._sentryDebugIdIdentifier="sentry-dbid-1e4411b6-ce59-4566-b12e-53aac34e3ce2")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var a;return s(),l(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[f(n(d))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(s(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.9833e445.js.map
