import{C as y}from"./ContentLayout.aeecd886.js";import{d as w,L as c,N as b,e as g,o as a,c as n,w as l,b as i,u as o,ev as s}from"./vue-router.637ad36e.js";import{K as _,_ as v,W as K,E,a as R}from"./WorkflowView.150d9829.js";import{E as T}from"./api.fb2155e2.js";import{A as p,T as V}from"./TabPane.db2c1289.js";import"./fetch.a7f25938.js";import"./linters.45f0bd9a.js";import"./asyncComputed.0b7f3eaf.js";import"./scripts.9fe343da.js";import"./record.833ab838.js";import"./metadata.9cd5a8e3.js";import"./PhCheckCircle.vue.92a8a97d.js";import"./PhKanban.vue.0ae2296c.js";import"./PhWebhooksLogo.vue.3f87c53c.js";import"./ant-design.5377a580.js";import"./index.faf7cd82.js";import"./index.ba283bad.js";import"./index.477bbb1c.js";import"./index.c0d6d885.js";import"./CollapsePanel.703584f9.js";import"./index.5388dc8c.js";import"./index.cf05a826.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.5e489784.js";import"./model.9e62b22b.js";import"./workspaces.29615a64.js";import"./runnerData.8e7195b2.js";import"./url.c1cbace3.js";import"./validations.2be13234.js";import"./string.876500c9.js";import"./PhArrowSquareOut.vue.69153380.js";import"./index.292db4f5.js";import"./Badge.7cdb210c.js";import"./index.13a24099.js";import"./Card.6af2f5b2.js";import"./uuid.9a0cf3c3.js";import"./LoadingOutlined.e5ed65d8.js";import"./DeleteOutlined.b63ba760.js";import"./PhDownloadSimple.vue.8d040345.js";import"./utils.85ed511a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f4566e11-629f-49ae-b27f-f15d773f8adb",e._sentryDebugIdIdentifier="sentry-dbid-f4566e11-629f-49ae-b27f-f15d773f8adb")}catch{}})();const ko=w({__name:"WorkflowThreads",setup(e){const t=new E,m=new R,d=new c(b.array(b.string()),"kanban-selected-stages"),u=new T,r=g("kanban");return(W,f)=>(a(),n(y,{"full-width":""},{default:l(()=>[i(o(V),{activeKey:r.value,"onUpdate:activeKey":f[0]||(f[0]=k=>r.value=k)},{default:l(()=>[i(o(p),{key:"kanban",tab:"Kanban View"}),i(o(p),{key:"table",tab:"Table View"}),i(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),r.value==="kanban"?(a(),n(_,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(d),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),r.value==="table"?(a(),n(v,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),r.value==="workflow"?(a(),n(K,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{ko as default};
//# sourceMappingURL=WorkflowThreads.f61d82aa.js.map
