import{P as m}from"./PlayerNavbar.339cd786.js";import{u as _,b as f}from"./router.c2ded2b1.js";import{d as h,eM as g,eA as s,f as b,r as y,o as v,et as w,b as r,u as i,a as L,R as I}from"./vue-router.637ad36e.js";import"./metadata.9cd5a8e3.js";import"./PhCheckCircle.vue.92a8a97d.js";import"./PhKanban.vue.0ae2296c.js";import"./PhWebhooksLogo.vue.3f87c53c.js";import"./asyncComputed.0b7f3eaf.js";import"./PhSignOut.vue.215a4e1f.js";import"./api.2921acd7.js";import"./runnerData.8e7195b2.js";import"./url.c1cbace3.js";import"./index.b59203d3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="16a918ee-da36-442d-abdc-217092b4a28b",t._sentryDebugIdIdentifier="sentry-dbid-16a918ee-da36-442d-abdc-217092b4a28b")}catch{}})();const k={class:"main-container"},N={class:"content"},R=h({__name:"Main",setup(t){const e=g(),o=_(),c=s().path,u=({path:n})=>{e.push({path:`/${n}`})},d=()=>{e.push({name:"playerLogin"})},p=b(()=>!!s().meta.hideLogin);return f(()=>e.push({name:"playerLogin"})),(n,x)=>{var a;const l=y("RouterView");return v(),w("div",k,[r(m,{"current-path":i(c),"user-email":(a=i(o).user)==null?void 0:a.claims.email,onNavigate:u,onLoginClick:d,"hide-login":p.value},null,8,["current-path","user-email","hide-login"]),L("section",N,[r(l)])])}}});const q=I(R,[["__scopeId","data-v-c786764c"]]);export{q as default};
//# sourceMappingURL=Main.0bb2330e.js.map
