import"./vue-router.637ad36e.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="84be49c8-ed2b-40a0-bd9e-89f3bb17a60a",x._sentryDebugIdIdentifier="sentry-dbid-84be49c8-ed2b-40a0-bd9e-89f3bb17a60a")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{d as u};
//# sourceMappingURL=uuid.9a0cf3c3.js.map
