import{b as f,eE as i,eO as u}from"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fe441354-ef78-4abc-80c0-79c3aaacdacc",e._sentryDebugIdIdentifier="sentry-dbid-fe441354-ef78-4abc-80c0-79c3aaacdacc")}catch{}})();function o(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){d(e,a,n[a])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var c=function(t,n){var r=o({},t,n.attrs);return f(i,o({},r,{icon:u}),null)};c.displayName="DownOutlined";c.inheritAttrs=!1;const s=c;export{s as D};
//# sourceMappingURL=DownOutlined.38a21894.js.map
