html,body{overscroll-behavior-x:none}.workflow-editor[data-v-de9c06f6]{position:relative;display:flex;flex-grow:1;height:100%;width:100%}.workflow-editor .workflow-toolbar[data-v-de9c06f6]{display:flex;position:absolute;left:50%;bottom:2%;flex-direction:row;background-color:#fff;align-items:center;gap:18px;padding:5px 10px;box-shadow:0 0 5px #0003;transform:translate(-50%);border-radius:5px}.workflow-editor .workflow-toolbar .toolbar-item[data-v-de9c06f6]{cursor:grab}.workflow-editor .workflow-toolbar .toolbar-item[data-v-de9c06f6]:hover{box-shadow:0 0 5px #0003;transform:rotate(-5deg)}
