import{d as t,o,et as s,b as a,u as r,bj as _,R as c}from"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="55b41db9-b34d-4af0-846f-cd8d0d59e952",e._sentryDebugIdIdentifier="sentry-dbid-55b41db9-b34d-4af0-846f-cd8d0d59e952")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,d)=>(o(),s("div",i,[a(r(_))]))}});const p=c(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.52569e84.js.map
