.selection-menu[data-v-54ac313a]{position:absolute;user-select:none;top:0;left:0;pointer-events:initial;border-radius:12px;z-index:2}.menu-item[data-v-54ac313a]{display:flex;justify-content:space-between;align-items:center;height:100%;gap:20px}.base-badge[data-v-6123b676]{display:flex;align-items:center;justify-content:center;gap:4px;background-color:#fff;color:#999;box-shadow:0 0 0 1px #d9d9d9 inset;border-radius:10px;height:20px;min-width:20px;line-height:20px;padding:0 8px}.pointer[data-v-733a02b2]{cursor:pointer}.stage-card[data-v-733a02b2]{outline:none;transition:transform 0 ease-in-out;position:absolute;user-select:none;top:0;left:0;pointer-events:initial;max-width:300px}.stage-card[data-v-733a02b2] .ant-card-body{padding:10px 15px}.stage-card.editing[data-v-733a02b2]{z-index:1;min-width:300px}.stage-card.editing[data-v-733a02b2] .bodyLess .ant-card-head{border:0}.stage-card.selected .card[data-v-733a02b2]{border:1px solid var(--3ea13526)}.ant-form-item[data-v-733a02b2]{margin-bottom:0}.title-input[data-v-733a02b2]{border-bottom:1px solid #d9d9d9;border-radius:0;margin-right:12px}.title-text[data-v-733a02b2]{margin-left:12px}.pointer[data-v-c354a0ec]{cursor:pointer}.transition-card[data-v-c354a0ec]{outline:none;display:flex;gap:5px;align-items:center;border-radius:2px;width:fit-content;position:absolute;user-select:none;top:0;left:0;pointer-events:initial;font-size:15px}.transition-card.selected[data-v-c354a0ec]{border-color:#000}.transition-card .editing .selector[data-v-c354a0ec]{min-width:200px}.empty-hint[data-v-372252af]{position:absolute;top:0;left:0;width:100%;height:100%;pointer-events:none}.empty-hint .drag-hint[data-v-372252af]{top:75%;left:50%;width:100px;transform:translate(-50%)}.empty-hint .drag-hint .arrow[data-v-372252af]{animation:left-arrow-372252af 1s infinite}@keyframes left-arrow-372252af{0%{transform:translateY(-2px)}50%{transform:translateY(2px)}to{transform:translateY(-2px)}}.empty-hint .drop-hint[data-v-372252af]{top:50%;left:50%;transform:translate(-50%,-50%)}.empty-hint .drop-hint .arrow[data-v-372252af]{animation:down-arrow-372252af 1s infinite}@keyframes down-arrow-372252af{0%{transform:translateY(-5px)}50%{transform:translateY(5px)}to{transform:translateY(-5px)}}.empty-hint .stages-hint[data-v-372252af]{top:50%;left:50%;transform:translate(-50%,-50%);display:grid;gap:90px;grid-template-columns:repeat(3,1fr);position:absolute;color:#a0a0a0;font-size:20px;font-weight:500;text-align:center}.empty-hint .stages-hint .stage-hint[data-v-372252af]{display:flex;flex-direction:column;gap:10px}.empty-hint .stages-hint .stage-hint .header[data-v-372252af]{display:flex;align-items:center;justify-content:center;gap:10px}.empty-hint .stages-hint .stage-hint .header .title[data-v-372252af]{font-size:22px;font-weight:700}.empty-hint .stages-hint .stage-hint .description[data-v-372252af]{font-size:18px;font-weight:400}.empty-hint .drag-hint[data-v-372252af],.empty-hint .drop-hint[data-v-372252af]{position:absolute;color:#a0a0a0;font-size:20px;font-weight:500;text-align:center;display:flex;flex-direction:column;align-items:center;gap:16px}.empty-hint .drag-hint .title[data-v-372252af],.empty-hint .drop-hint .title[data-v-372252af]{font-size:20px;font-weight:500}.empty-hint .drag-hint .arrow[data-v-372252af],.empty-hint .drop-hint .arrow[data-v-372252af]{width:40px;height:40px;color:#a0a0a0}.canvas-container[data-v-5f36b283]{flex-grow:1;flex-basis:0;position:relative;overflow:hidden;outline:none}.canvas-container[data-v-5f36b283]:focus{border:4px solid #ebebeb}.canvas-container .icon[data-v-5f36b283]{position:absolute;top:10px;left:20px;cursor:pointer;z-index:1;color:gray}.canvas-container .icon.disabled[data-v-5f36b283]{opacity:.4;pointer-events:none}.canvas-container .icon.undo[data-v-5f36b283]{left:20px}.canvas-container .icon.redo[data-v-5f36b283]{left:50px}.canvas-container .workflow-canvas[data-v-5f36b283]{position:absolute;top:0;left:0;width:100%;height:100%;user-select:none;background-color:#eaeaea}.canvas-container .items-container[data-v-5f36b283]{position:absolute;top:0px;left:0px;width:100%;height:100%;pointer-events:none}
