import{a6 as d,dh as s}from"./vue-router.637ad36e.js";import{g as i}from"./index.344da30b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="27d72041-2454-4498-a816-15cb4d199adc",e._sentryDebugIdIdentifier="sentry-dbid-27d72041-2454-4498-a816-15cb4d199adc")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:m,TimePicker:f,QuarterPicker:o,RangePicker:a}=i(s),y=d(n,{WeekPicker:r,MonthPicker:t,YearPicker:m,RangePicker:a,TimePicker:f,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,a as R,r as W};
//# sourceMappingURL=dayjs.38ec6eef.js.map
