import{a as g}from"./asyncComputed.0b7f3eaf.js";import{d as y,eA as _,Z as b,u as e,o as c,c as w,et as x,b as a,w as o,cR as C,ar as l,cV as h,bG as I,a as k,ez as v}from"./vue-router.637ad36e.js";import"./gateway.e1c89e24.js";import"./tables.0c659977.js";import{O as z}from"./organization.0cc361ba.js";import{C as p}from"./router.3a426b39.js";import{L as B}from"./LoadingContainer.52569e84.js";import{A as D}from"./index.5388dc8c.js";import{C as N}from"./Card.6af2f5b2.js";import"./popupNotifcation.498cf509.js";import"./record.833ab838.js";import"./string.876500c9.js";import"./TabPane.db2c1289.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="bedadccc-ba24-45c7-9866-543c6c584c10",t._sentryDebugIdIdentifier="sentry-dbid-bedadccc-ba24-45c7-9866-543c6c584c10")}catch{}})();const A={key:1},M={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},J=y({__name:"Billing",setup(t){const s=_().params.organizationId,{loading:u,result:f}=g(()=>z.get(s));b(()=>{location.search.includes("upgrade")&&p.showNewMessage("I want to upgrade my plan")});const m=()=>p.showNewMessage("I want to upgrade my plan");return(V,j)=>e(u)?(c(),w(B,{key:0})):(c(),x("div",A,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(C),{level:3},{default:o(()=>[l("Current plan")]),_:1})]),_:1}),a(e(D),{style:{"margin-top":"0"}}),a(e(N),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[l("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",M,v((d=(i=(r=e(f))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{J as default};
//# sourceMappingURL=Billing.96423288.js.map
