import{eZ as t,e_ as r}from"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9b807388-685f-498d-9d8a-af3f80315e6c",e._sentryDebugIdIdentifier="sentry-dbid-9b807388-685f-498d-9d8a-af3f80315e6c")}catch{}})();function a(e,n){return t(1,arguments),r(e,Date.now(),n)}export{a as f};
//# sourceMappingURL=index.477bbb1c.js.map
