import{u as a}from"./router.c2ded2b1.js";import{r as o,w as n}from"./runnerData.8e7195b2.js";import"./vue-router.637ad36e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="db2fb258-6b82-4f3f-9d4c-7ff1eddb70f0",t._sentryDebugIdIdentifier="sentry-dbid-db2fb258-6b82-4f3f-9d4c-7ff1eddb70f0")}catch{}})();async function i(t){const e=a(),r=await fetch(`/_pages/${t}`,{headers:e.authHeaders});if(r.status===404)return null;if(!r.ok)throw new Error(await r.text());const{form:s}=await r.json();return s?o(s):null}async function c(){const t=a(),e=await fetch("/_workspace",{headers:t.authHeaders});if(e.status!=200)return n({});const r=await e.json();return n(r)}export{i as f,c as g};
//# sourceMappingURL=api.2921acd7.js.map
