import{d as k,eM as A,r as B,u as e,o as s,c as i,bj as C,et as f,b as a,w as t,ar as r,bG as d,a as m,cQ as w,ez as _,cw as N,eK as D,eC as I,fd as L,aD as g,ev as z,dA as R,R as S}from"./vue-router.637ad36e.js";import{a as T}from"./asyncComputed.0b7f3eaf.js";import{G as V}from"./PhChats.vue.f3eef692.js";import{F as $}from"./PhSignOut.vue.215a4e1f.js";import{C as j}from"./router.3a426b39.js";import{a as h}from"./gateway.e1c89e24.js";import{A as E}from"./index.faf7cd82.js";import{A as F}from"./index.b59203d3.js";import{B as G,A as M,b as P}from"./index.9858c95f.js";import{B as q}from"./BookOutlined.c02a6591.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[o]="bbe16f5e-0759-400b-9575-de7f127b9e3d",n._sentryDebugIdIdentifier="sentry-dbid-bbe16f5e-0759-400b-9575-de7f127b9e3d")}catch{}})();const H={key:1,style:{display:"flex","align-items":"center",gap:"16px"}},K={style:{display:"flex","flex-direction":"column",gap:"10px"}},O={style:{display:"flex",gap:"5px"}},Q=k({__name:"LoginBlock",setup(n){function o(b){const y=b.split("@")[0];return D.exports.kebabCase(y).toUpperCase().split("-").slice(0,2).map(u=>u[0]).join("")}const c=A(),{result:l,loading:p,refetch:x}=T(async()=>h.getAuthor());function v(){h.removeAuthor(),j.shutdown(),x(),c.push({name:"login"})}return(b,y)=>{const u=B("RouterLink");return e(p)?(s(),i(e(C),{key:0})):e(l)?(s(),f("div",H,[a(e(d),{class:"intercom-launcher",target:"_blank",type:"link",size:"small",style:{color:"#d14056",display:"flex","align-items":"center",gap:"6px"}},{icon:t(()=>[a(e(V),{size:18})]),default:t(()=>[r(" Support ")]),_:1}),a(e(N),{placement:"bottomRight"},{content:t(()=>[m("div",K,[a(e(w),{size:"small",type:"secondary"},{default:t(()=>[r(_(e(l).claims.email),1)]),_:1}),a(e(d),{type:"text",onClick:v},{default:t(()=>[m("div",O,[a(e($),{size:"20"}),r(" Logout ")])]),_:1})])]),default:t(()=>[a(e(E),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(F),{shape:"square"},{default:t(()=>[r(_(o(e(l).claims.email)),1)]),_:1})]),_:1})]),_:1})])):(s(),i(e(d),{key:2},{default:t(()=>[a(u,{to:"/login"},{default:t(()=>[r("Login")]),_:1})]),_:1}))}}}),U={class:"extra"},J=k({__name:"Navbar",props:{breadcrumb:{}},setup(n){return(o,c)=>(s(),i(e(P),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[o.breadcrumb?(s(),i(e(G),{key:0},{default:t(()=>[(s(!0),f(g,null,I(o.breadcrumb,(l,p)=>(s(),i(e(M),{key:p},{default:t(()=>[a(e(L),{to:l.path},{default:t(()=>[r(_(l.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):z("",!0)]),extra:t(()=>[m("div",U,[a(e(d),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[a(e(q))]),default:t(()=>[o.$slots.default?R(o.$slots,"default",{key:0},void 0,!0):(s(),f(g,{key:1},[r("Docs")],64))]),_:3}),a(Q)])]),_:3}))}});const ne=S(J,[["__scopeId","data-v-5ef7b378"]]);export{ne as N};
//# sourceMappingURL=Navbar.599027a6.js.map
