import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.29f67e83.js";import{d as s,eA as i,o as a,c as m,u as d}from"./vue-router.637ad36e.js";import"./gateway.e1c89e24.js";import"./popupNotifcation.498cf509.js";import"./fetch.a7f25938.js";import"./record.833ab838.js";import"./SaveButton.9e326ad9.js";import"./ExclamationCircleOutlined.b054d85e.js";import"./CrudView.3cb1fb74.js";import"./router.3a426b39.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.9833e445.js";import"./BookOutlined.c02a6591.js";import"./url.c1cbace3.js";import"./index.ba283bad.js";import"./index.faf7cd82.js";import"./PhRocketLaunch.vue.c0fc87e0.js";import"./asyncComputed.0b7f3eaf.js";import"./PhPencil.vue.5353ab56.js";import"./index.13a24099.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="39039b2f-b684-4b82-9b46-dba1efe7c7b9",o._sentryDebugIdIdentifier="sentry-dbid-39039b2f-b684-4b82-9b46-dba1efe7c7b9")}catch{}})();const A=s({__name:"EnvVars",setup(o){const r=i().params.projectId,t=new p(r);return(c,f)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.2091d76c.js.map
