import{i as T}from"./url.c1cbace3.js";import"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="041762bf-240e-42db-9af8-f4760dd4886b",e._sentryDebugIdIdentifier="sentry-dbid-041762bf-240e-42db-9af8-f4760dd4886b")}catch{}})();function A(e,a,s){return a?T(a)?a:s==="player"?`/_assets/${e}`:`/_editor/api/assets/${a}`:null}const w="#414a58",F="#FFFFFF",L="#000000",y="DM Sans",E="Untitled Project",D={value:"en",label:"English"};function I(e){var a,s,n,r,t,l,o,i,u,_,f,m,c,g,b,p;return{id:e.id,path:e.path,theme:(a=e.workspace.theme)!=null?a:F,brandName:(s=e.workspace.brand_name)!=null?s:null,title:e.title,isInitial:e.is_initial,isLocal:(n=e.is_local)!=null?n:!1,startMessage:(r=e.start_message)!=null?r:null,endMessage:(t=e.end_message)!=null?t:null,errorMessage:(l=e.error_message)!=null?l:null,timeoutMessage:(o=e.timeout_message)!=null?o:null,startButtonText:(i=e.start_button_text)!=null?i:null,restartButtonText:(u=e.restart_button_text)!=null?u:null,logoUrl:e.workspace.logo_url,mainColor:(_=e.workspace.main_color)!=null?_:w,fontFamily:(f=e.workspace.font_family)!=null?f:y,autoStart:(m=e.auto_start)!=null?m:!1,allowRestart:e.allow_restart,welcomeTitle:(c=e.welcome_title)!=null?c:null,runtimeType:"form",language:(g=e.workspace.language)!=null?g:D.value,sidebar:(p=(b=e.workspace)==null?void 0:b.sidebar)!=null?p:[]}}function M(e){return{name:e.name||E,fontColor:e.font_color||L,sidebar:e.sidebar||[],brandName:e.brand_name||"",fontFamily:e.font_family||y,logoUrl:e.logo_url?A("logo",e.logo_url,"player"):null,mainColor:e.main_color||w,theme:e.theme||F,language:e.language||D.value}}export{w as D,y as a,D as b,F as c,A as m,I as r,M as w};
//# sourceMappingURL=runnerData.8e7195b2.js.map
