import"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="f22ea707-91a8-49c8-8df4-110523907884",e._sentryDebugIdIdentifier="sentry-dbid-f22ea707-91a8-49c8-8df4-110523907884")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}},o=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([s,a])=>{t.searchParams.delete(s),n.set(s,a)}),`${t.origin}${t.pathname}?${n.toString()}`};export{d as i,o as m};
//# sourceMappingURL=url.c1cbace3.js.map
