import{C as t,E as i,K as d,a as f,M as b,c as l,P as y,R as c,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.49c6baa3.js";import"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="81ef440e-6ebf-4961-b5fa-bb5d05af58e8",e._sentryDebugIdIdentifier="sentry-dbid-81ef440e-6ebf-4961-b5fa-bb5d05af58e8")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,f as KeyMod,b as MarkerSeverity,l as MarkerTag,y as Position,c as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.131a3cf7.js.map
