.menu-item{display:flex;gap:6px;align-items:center}.sidebar[data-v-51bc78c1]{height:100%;display:flex;flex-direction:column;background-color:#fff;border:solid 1px #f0f0f0}.sidebar .logo[data-v-51bc78c1]{display:flex;align-items:center;width:100%;padding:5px 0 5px 8px}.sidebar .toggle-button[data-v-51bc78c1]{display:flex;justify-content:end;padding:0 8px;cursor:pointer;margin-top:auto;margin-bottom:20px}.sidebar .disabled[data-v-51bc78c1]{cursor:not-allowed;opacity:.4}
