import{R as o,r as i,o as r,c,k as d,T as p,m as u,P as _,C as f,M as l,s as g,n as s,p as y,q as m,t as w,v}from"./vue-router.637ad36e.js";import{s as b,c as h,a}from"./router.c2ded2b1.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="60f071d9-e30a-45ed-8f6e-d73691428cb2",t._sentryDebugIdIdentifier="sentry-dbid-60f071d9-e30a-45ed-8f6e-d73691428cb2")}catch{}})();const I={};function k(t,e){const n=i("RouterView");return r(),c(n,{style:{height:"100vh",width:"100%"}})}const A=o(I,[["render",k]]);class D{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const t=h(),e=d({render:()=>y(A)});p.init(),u(e,a),D.init(),e.use(a),e.use(t),e.use(_),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",g),s(e,m),s(e,w),s(e,v)})();
//# sourceMappingURL=player.95dc676e.js.map
