import{O as d}from"./router.c2ded2b1.js";import{d as l,Z as c,o as u,et as i,b as a,w as o,u as n,ar as s,cR as f,cQ as b}from"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2578bee4-6e5c-40df-bfdb-5cb4a3e09f78",e._sentryDebugIdIdentifier="sentry-dbid-2578bee4-6e5c-40df-bfdb-5cb4a3e09f78")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return c(async()=>{await new d().logoutCallback()}),(t,r)=>(u(),i("div",null,[a(n(f),null,{default:o(()=>[s("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.d451c876.js.map
