import{d,o as s,et as t,ev as n,eH as c,eI as _,a as r,R as p}from"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="67c86e50-967b-4496-856a-fc0e411f1b75",e._sentryDebugIdIdentifier="sentry-dbid-67c86e50-967b-4496-856a-fc0e411f1b75")}catch{}})();const i="/assets/logo.0faadfa2.svg",f=e=>(c("data-v-a421cbdb"),e=e(),_(),e),l={class:"logo"},b=f(()=>r("img",{class:"logo-img",src:i,alt:"Abstra Logo"},null,-1)),g={key:0},u=d({__name:"Logo",props:{hideText:{type:Boolean}},setup(e){return(o,a)=>(s(),t("div",l,[b,o.hideText?n("",!0):(s(),t("span",g,"Abstra"))]))}});const m=p(u,[["__scopeId","data-v-a421cbdb"]]);export{m as L};
//# sourceMappingURL=Logo.48fe3cc3.js.map
