import{B as f}from"./BaseLayout.00638592.js";import{L as y}from"./Logo.48fe3cc3.js";import{d as l,D as m,K as b,R as p,aL as g,aM as v,o as _,et as h,a as s,eu as n,eA as w,eM as L,Z as S,c as k,w as r,b as i,u as x}from"./vue-router.637ad36e.js";import{u as B}from"./editor.ba631111.js";import{b as I}from"./index.9858c95f.js";import"./router.c2ded2b1.js";import"./linters.45f0bd9a.js";import"./asyncComputed.0b7f3eaf.js";import"./index.b59203d3.js";import"./index.faf7cd82.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a38fccab-b418-4a34-90e5-cbfd83e3a972",e._sentryDebugIdIdentifier="sentry-dbid-a38fccab-b418-4a34-90e5-cbfd83e3a972")}catch{}})();const D=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const a=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(a)}}});const P={class:"v-spinner"};function R(e,a,o,c,d,u){return g((_(),h("div",P,[s("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),s("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),s("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[v,e.loading]])}const $=p(D,[["render",R],["__scopeId","data-v-06538001"]]),K={class:"content"},j=l({__name:"ProjectLogin",setup(e){const a=w(),o=L(),c=B();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function u(){const t=a.query["api-key"];if(typeof t=="string")return t}return S(async()=>{const t=u();if(!t){o.push({name:"error"});return}await c.createLogin(t).then(d),o.push({name:"workspace"})}),(t,z)=>(_(),k(f,null,{navbar:r(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:r(()=>[i(y)]),_:1})]),content:r(()=>[s("div",K,[i($)])]),_:1}))}});const Z=p(j,[["__scopeId","data-v-6ca995fe"]]);export{Z as default};
//# sourceMappingURL=ProjectLogin.23b2cbce.js.map
