.flex-row[data-v-da0ef620]{display:flex;flex-direction:row;align-items:center;justify-content:right;gap:5px;height:100%;width:100%}.trigger-buttons[data-v-44f8a783]{display:flex;gap:8px;font-size:14px;color:gray}.trigger-buttons>*[data-v-44f8a783]{cursor:pointer}.trigger-buttons>*[data-v-44f8a783] :hover{color:#f28392}.trigger-buttons>*[data-v-44f8a783] :active{color:#f28392}.centered[data-v-44f8a783]{display:flex;flex-direction:column;gap:16px;padding:32px}.icon[data-v-44f8a783]{margin:0 0 -2px 4px}.ellipsis[data-v-44f8a783]{max-width:240px;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}
