import{O as d}from"./router.c2ded2b1.js";import{d as c,Z as l,o as i,et as u,b as t,w as n,u as o,ar as s,cR as f,cQ as b}from"./vue-router.637ad36e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="d5c70659-436f-439c-b7ec-fc1709a6aab6",e._sentryDebugIdIdentifier="sentry-dbid-d5c70659-436f-439c-b7ec-fc1709a6aab6")}catch{}})();const p=c({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new d().loginCallback()}),(a,r)=>(i(),u("div",null,[t(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),t(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.c7fcc451.js.map
