import{d as i,o as n,c as p,w as d,b as a,u as t}from"./vue-router.637ad36e.js";import"./linters.45f0bd9a.js";import{W as s}from"./workspaces.29615a64.js";import{C as m}from"./ContentLayout.aeecd886.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.29f67e83.js";import"./asyncComputed.0b7f3eaf.js";import"./runnerData.8e7195b2.js";import"./url.c1cbace3.js";import"./record.833ab838.js";import"./gateway.e1c89e24.js";import"./popupNotifcation.498cf509.js";import"./fetch.a7f25938.js";import"./SaveButton.9e326ad9.js";import"./ExclamationCircleOutlined.b054d85e.js";import"./CrudView.3cb1fb74.js";import"./router.3a426b39.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.9833e445.js";import"./BookOutlined.c02a6591.js";import"./index.ba283bad.js";import"./index.faf7cd82.js";import"./PhRocketLaunch.vue.c0fc87e0.js";import"./PhPencil.vue.5353ab56.js";import"./index.13a24099.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="6bdcd173-7a84-4f39-8790-b2d687d71fba",o._sentryDebugIdIdentifier="sentry-dbid-6bdcd173-7a84-4f39-8790-b2d687d71fba")}catch{}})();const q=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(n(),p(m,null,{default:d(()=>[a(f,{"env-var-repository":t(r),mode:"editor","file-opender":t(s)},null,8,["env-var-repository","file-opender"])]),_:1}))}});export{q as default};
//# sourceMappingURL=EnvVarsEditor.db1fda5e.js.map
